@@ -2,7 +2,7 @@
     Supposed to use with ``Request`` object or something like that.
 """
 from collections import Mapping
-from . import Trafaret, DataError, Key, catch_error
+from . import Trafaret, DataError, Key, catch_error, _empty
 
 
 def get_deep_attr(obj, keys):
@@ -42,10 +42,10 @@ class DeepKey(Key):
 
     def pop(self, data):
         try:
-            yield self.get_name(),  catch_error(self.trafaret,
+            yield self.get_name(), catch_error(self.trafaret,
                     get_deep_attr(data, self.name.split('.')))
         except DataError as e:
-            if self.default:
+            if self.default != _empty:
                 yield self.get_name(), self.default
             elif not self.optional:
                 yield self.name, e
